Crate ratatui_toolkit

Crate ratatui_toolkit 

ratatui-toolkit (deprecated)

This crate has been renamed to ratkit. Please migrate by replacing:

  • ratatui-toolkit -> ratkit in Cargo.toml
  • ratatui_toolkit -> ratkit in Rust imports

This crate is now only a compatibility shim that re-exports ratkit.

Modules

core
Core runtime pieces for ratkit. Core runtime types and runner.
preludeDeprecated
primitives
Feature-gated primitive widget modules.
services
Feature-gated service modules.
widgets
Feature-gated widget modules (includes primitives for backward compatibility).

Structs

CoordinatorConfig
ElementHandle
Handle to a registered element.
ElementId
Unique identifier for a UI element.
ElementMetadata
Metadata about a registered element.
KeyboardEvent
A keyboard input event.
LayoutCoordinator
MouseEvent
A mouse input event.
MouseRouterConfig
RedrawSignal
A cloneable signal for requesting a redraw from any thread.
ResizeEvent
A terminal resize event.
Runner
Core runtime runner coordinating event dispatch and render passes.
RunnerConfig
Runner configuration for event cadence and routing.
TickEvent
A periodic tick event.

Enums

CoordinatorAction
CoordinatorEvent
FocusRequest
Focus change request type.
LayoutError
Errors that can occur in the layout manager.
RunnerAction
Action requested by the runner after handling an event.
Visibility
Visibility state of an element.

Constants

DEPRECATION_NOTICEDeprecated

Traits

CoordinatorApp
Element
Trait for elements that can be registered with the layout manager.

Functions

run
Run a coordinator application with the ratkit core runtime.
run_with_diagnostics
Run a coordinator application with diagnostics overlay enabled.

Type Aliases

LayoutResult
Result type alias for layout operations.
RunnerEvent
Runner events routed to the core runtime.