Module core

Module core 

Core runtime pieces for ratkit. Core runtime types and runner.

Modules

runner
Core runner coordinating layout and event dispatch.

Structs

CoordinatorConfig
ElementHandle
Handle to a registered element.
ElementId
Unique identifier for a UI element.
ElementMetadata
Metadata about a registered element.
KeyboardEvent
A keyboard input event.
LayoutCoordinator
MouseEvent
A mouse input event.
MouseRouterConfig
RedrawSignal
A cloneable signal for requesting a redraw from any thread.
ResizeEvent
A terminal resize event.
Runner
Core runtime runner coordinating event dispatch and render passes.
RunnerConfig
Runner configuration for event cadence and routing.
TickEvent
A periodic tick event.

Enums

CoordinatorAction
CoordinatorEvent
FocusRequest
Focus change request type.
LayoutError
Errors that can occur in the layout manager.
RunnerAction
Action requested by the runner after handling an event.
Visibility
Visibility state of an element.

Traits

CoordinatorApp
Element
Trait for elements that can be registered with the layout manager.

Type Aliases

LayoutResult
Result type alias for layout operations.
RunnerEvent
Runner events routed to the core runtime.