Module runner

Module runner 

Core runner coordinating layout and event dispatch.

Structs

Runner
Core runtime runner coordinating event dispatch and render passes.
RunnerConfig
Runner configuration for event cadence and routing.

Enums

RunnerAction
Action requested by the runner after handling an event.

Type Aliases

RunnerEvent
Runner events routed to the core runtime.