pub struct RedrawSignal { /* private fields */ }Expand description
A cloneable signal for requesting a redraw from any thread.
Implementations
Sourceimpl RedrawSignal
impl RedrawSignal
Sourcepub fn new() -> RedrawSignal
pub fn new() -> RedrawSignal
Create a new signal.
Starts in the clean state (no redraw requested).
Sourcepub fn request_redraw(&self)
pub fn request_redraw(&self)
Request a redraw.
Sourcepub fn is_redraw_requested(&self) -> bool
pub fn is_redraw_requested(&self) -> bool
Returns true if a redraw is currently requested.
Sourcepub fn take_redraw_request(&self) -> bool
pub fn take_redraw_request(&self) -> bool
Consume and clear the redraw request flag.
Returns true if a redraw had been requested since the last consume.