pub struct Cell { /* private fields */ }Available on crate feature
termtui only.Expand description
Represents a single terminal cell.
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn contents(&self) -> &str
pub fn contents(&self) -> &str
Returns the text contents of the cell.
Can include multiple unicode characters if combining characters are used, but will contain at most one character with a non-zero character width.
Sourcepub fn has_contents(&self) -> bool
pub fn has_contents(&self) -> bool
Returns whether the cell contains any text data.
Sourcepub fn is_wide(&self) -> bool
pub fn is_wide(&self) -> bool
Returns whether the text data in the cell represents a wide character.
pub fn width(&self) -> u16