Parser

Struct Parser 

pub struct Parser {
    pub screen: Screen,
}
Available on crate feature termtui only.
A parser for terminal output which produces an in-memory representation of the terminal contents.

Fields

screen: Screen

Implementations

Source

impl Parser

pub fn new(rows: u16, cols: u16, scrollback_len: usize) -> Parser

Creates a new terminal parser of the given size and with the given amount of scrollback.

pub fn set_size(&mut self, rows: u16, cols: u16)

Resizes the terminal.

pub fn set_scrollback(&mut self, rows: usize)

Scrolls to the given position in the scrollback.

This position indicates the offset from the top of the screen, and should be 0 to put the normal screen in view.

This affects the return values of methods called on parser.screen(): for instance, parser.screen().cell(0, 0) will return the top left corner of the screen after taking the scrollback offset into account. It does not affect parser.process() at all.

The value given will be clamped to the actual size of the scrollback.

pub fn screen(&self) -> &Screen

Returns a reference to a Screen object containing the terminal state.