Module widget_event

Module widget_event 

Available on crate feature widget-event only.
Common events emitted by interactive widgets.

This module provides a unified event system that all interactive widgets can use to communicate actions back to the parent application.

Enums

WidgetEvent
Common events emitted by interactive widgets.