pub struct Runner<A>where
A: CoordinatorApp,{ /* private fields */ }Expand description
Core runtime runner coordinating event dispatch and render passes.
Implementations
Sourceimpl<A> Runner<A>where
A: CoordinatorApp,
impl<A> Runner<A>where
A: CoordinatorApp,
Sourcepub fn with_config(self, config: RunnerConfig) -> Runner<A>
pub fn with_config(self, config: RunnerConfig) -> Runner<A>
Apply a custom runner configuration.
Sourcepub fn coordinator(&self) -> &LayoutCoordinator<A>
pub fn coordinator(&self) -> &LayoutCoordinator<A>
Access the underlying coordinator.
Sourcepub fn coordinator_mut(&mut self) -> &mut LayoutCoordinator<A>
pub fn coordinator_mut(&mut self) -> &mut LayoutCoordinator<A>
Mutable access to the underlying coordinator.
Sourcepub fn config(&self) -> RunnerConfig
pub fn config(&self) -> RunnerConfig
Runner configuration.
Sourcepub fn tick_count(&self) -> u64
pub fn tick_count(&self) -> u64
Current tick count.
Sourcepub fn handle_event(
&mut self,
event: RunnerEvent,
) -> Result<RunnerAction, LayoutError>
pub fn handle_event( &mut self, event: RunnerEvent, ) -> Result<RunnerAction, LayoutError>
Handle a runner event and return the desired action.
Sourcepub fn handle_coordinator_event(
&mut self,
event: CoordinatorEvent,
) -> Result<RunnerAction, LayoutError>
pub fn handle_coordinator_event( &mut self, event: CoordinatorEvent, ) -> Result<RunnerAction, LayoutError>
Handle coordinator events that are outside the standard input stream.
Sourcepub fn handle_tick(
&mut self,
tick: TickEvent,
) -> Result<RunnerAction, LayoutError>
pub fn handle_tick( &mut self, tick: TickEvent, ) -> Result<RunnerAction, LayoutError>
Handle a tick event and update the tick counter.
Sourcepub fn register_element(
&mut self,
metadata: ElementMetadata,
element: Arc<dyn Element>,
) -> Result<RunnerAction, LayoutError>
pub fn register_element( &mut self, metadata: ElementMetadata, element: Arc<dyn Element>, ) -> Result<RunnerAction, LayoutError>
Register a new element with the runtime.
Sourcepub fn unregister_element(
&mut self,
id: ElementId,
) -> Result<RunnerAction, LayoutError>
pub fn unregister_element( &mut self, id: ElementId, ) -> Result<RunnerAction, LayoutError>
Remove an element from the runtime.
Sourcepub fn set_visibility(
&mut self,
id: ElementId,
visibility: Visibility,
) -> Result<RunnerAction, LayoutError>
pub fn set_visibility( &mut self, id: ElementId, visibility: Visibility, ) -> Result<RunnerAction, LayoutError>
Update element visibility.
Sourcepub fn request_focus(
&mut self,
request: FocusRequest,
) -> Result<RunnerAction, LayoutError>
pub fn request_focus( &mut self, request: FocusRequest, ) -> Result<RunnerAction, LayoutError>
Apply a focus change request.
Sourcepub fn needs_redraw(&self) -> bool
pub fn needs_redraw(&self) -> bool
Whether the runner should redraw based on dirty state.