Cell

Struct Cell 

pub struct Cell { /* private fields */ }
Represents a single terminal cell.

Implementations

Source

impl Cell

pub fn contents(&self) -> &str

Available on crate feature termtui only.

Returns the text contents of the cell.

Can include multiple unicode characters if combining characters are used, but will contain at most one character with a non-zero character width.

pub fn has_contents(&self) -> bool

Available on crate feature termtui only.

Returns whether the cell contains any text data.

pub fn is_wide(&self) -> bool

Available on crate feature termtui only.

Returns whether the text data in the cell represents a wide character.

pub fn width(&self) -> u16

Available on crate feature termtui only.