pub struct DisplaySettings {
pub show_line_numbers: bool,
pub show_document_line_numbers: bool,
pub code_block_theme: CodeBlockTheme,
pub show_heading_collapse: bool,
pub scroll_multiplier: usize,
}Expand description
Display settings for markdown rendering.
Controls visual options like line numbers, themes, and collapse indicators.
Fields
show_line_numbers: boolWhether to show line numbers in code blocks.
show_document_line_numbers: boolWhether to show line numbers for the entire document.
code_block_theme: CodeBlockThemeColor theme for code blocks.
show_heading_collapse: boolWhether to show collapse indicators on headings.
scroll_multiplier: usizeScroll multiplier (lines per scroll tick).
Implementations
Sourceimpl DisplaySettings
impl DisplaySettings
Sourcepub fn new() -> DisplaySettings
Available on crate feature markdown-preview only.
pub fn new() -> DisplaySettings
markdown-preview only.Create new display settings with defaults.
Sourcepub fn set_code_block_theme(&mut self, theme: CodeBlockTheme) -> bool
Available on crate feature markdown-preview only.
pub fn set_code_block_theme(&mut self, theme: CodeBlockTheme) -> bool
markdown-preview only.Sourcepub fn set_scroll_multiplier(&mut self, multiplier: usize) -> bool
Available on crate feature markdown-preview only.
pub fn set_scroll_multiplier(&mut self, multiplier: usize) -> bool
markdown-preview only.Sourcepub fn scroll_multiplier(&self) -> usize
Available on crate feature markdown-preview only.
pub fn scroll_multiplier(&self) -> usize
markdown-preview only.Get the current scroll multiplier.
Sourcepub fn set_show_document_line_numbers(&mut self, show: bool) -> bool
Available on crate feature markdown-preview only.
pub fn set_show_document_line_numbers(&mut self, show: bool) -> bool
markdown-preview only.Sourcepub fn set_show_heading_collapse(&mut self, show: bool) -> bool
Available on crate feature markdown-preview only.
pub fn set_show_heading_collapse(&mut self, show: bool) -> bool
markdown-preview only.Trait Implementations
Sourceimpl Clone for DisplaySettings
impl Clone for DisplaySettings
Sourcefn clone(&self) -> DisplaySettings
fn clone(&self) -> DisplaySettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisplaySettings
impl Debug for DisplaySettings
Sourceimpl Default for DisplaySettings
impl Default for DisplaySettings
Sourcefn default() -> DisplaySettings
fn default() -> DisplaySettings
Returns the “default value” for a type. Read more