pub struct Parser {
pub screen: Screen,
}Expand description
A parser for terminal output which produces an in-memory representation of the terminal contents.
Fields
screen: ScreenImplementations
Sourceimpl Parser
impl Parser
Sourcepub fn new(rows: u16, cols: u16, scrollback_len: usize) -> Parser
Available on crate feature termtui only.
pub fn new(rows: u16, cols: u16, scrollback_len: usize) -> Parser
termtui only.Creates a new terminal parser of the given size and with the given amount of scrollback.
Sourcepub fn set_size(&mut self, rows: u16, cols: u16)
Available on crate feature termtui only.
pub fn set_size(&mut self, rows: u16, cols: u16)
termtui only.Resizes the terminal.
Sourcepub fn set_scrollback(&mut self, rows: usize)
Available on crate feature termtui only.
pub fn set_scrollback(&mut self, rows: usize)
termtui only.Scrolls to the given position in the scrollback.
This position indicates the offset from the top of the screen, and
should be 0 to put the normal screen in view.
This affects the return values of methods called on parser.screen():
for instance, parser.screen().cell(0, 0) will return the top left
corner of the screen after taking the scrollback offset into account.
It does not affect parser.process() at all.
The value given will be clamped to the actual size of the scrollback.