Modules
- core
- Core runtime pieces for ratkit. Core runtime types and runner.
- prelude
Deprecated - primitives
- Feature-gated primitive widget modules.
- services
- Feature-gated service modules.
- widgets
- Feature-gated widget modules (includes primitives for backward compatibility).
Structs
- Coordinator
Config - Element
Handle - Handle to a registered element.
- Element
Id - Unique identifier for a UI element.
- Element
Metadata - Metadata about a registered element.
- Keyboard
Event - A keyboard input event.
- Layout
Coordinator - Mouse
Event - A mouse input event.
- Mouse
Router Config - Redraw
Signal - A cloneable signal for requesting a redraw from any thread.
- Resize
Event - A terminal resize event.
- Runner
- Core runtime runner coordinating event dispatch and render passes.
- Runner
Config - Runner configuration for event cadence and routing.
- Tick
Event - A periodic tick event.
Enums
- Coordinator
Action - Coordinator
Event - Focus
Request - Focus change request type.
- Layout
Error - Errors that can occur in the layout manager.
- Runner
Action - Action requested by the runner after handling an event.
- Visibility
- Visibility state of an element.
Constants
- DEPRECATION_
NOTICE Deprecated
Traits
- Coordinator
App - Element
- Trait for elements that can be registered with the layout manager.
Functions
- run
- Run a coordinator application with the ratkit core runtime.
- run_
with_ diagnostics - Run a coordinator application with diagnostics overlay enabled.
Type Aliases
- Layout
Result - Result type alias for layout operations.
- Runner
Event - Runner events routed to the core runtime.