Available on crate feature
widget-event only.Expand description
Common events emitted by interactive widgets.
This module provides a unified event system that all interactive widgets can use to communicate actions back to the parent application.
Enums
- Widget
Event - Common events emitted by interactive widgets.