pub struct Cell { /* private fields */ }Expand description
Represents a single terminal cell.
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn contents(&self) -> &str
Available on crate feature termtui only.
pub fn contents(&self) -> &str
termtui only.Returns the text contents of the cell.
Can include multiple unicode characters if combining characters are used, but will contain at most one character with a non-zero character width.
Sourcepub fn has_contents(&self) -> bool
Available on crate feature termtui only.
pub fn has_contents(&self) -> bool
termtui only.Returns whether the cell contains any text data.
Sourcepub fn is_wide(&self) -> bool
Available on crate feature termtui only.
pub fn is_wide(&self) -> bool
termtui only.Returns whether the text data in the cell represents a wide character.
pub fn width(&self) -> u16
Available on crate feature
termtui only.Trait Implementations
impl Eq for Cell